@@ -12,8 +12,9 @@ def deleteTask(pid):
 
 
 def updateTask(tasks):
-    return rq.put("http://localhost:8000/task", data=json.dumps(tasks)).json()
+    return rq.put("http://localhost:8000/task", json=tasks).json()
 
 
 def addTask(tasks):
-    return rq.post("http://localhost:8000/task", data=json.dumps(tasks)).json()
\ No newline at end of file
+    res =  rq.post("http://localhost:8000/task", json=tasks)
+    return res.json()
\ No newline at end of file
