@@ -12,13 +12,15 @@ def consumer():
             path = Path(task["scriptPath"])
             task["running"] = True
             updateTask([task])
-            pipe = Pipe(command=f'{task["shell"]} {path.__str__()}', current_directory=path.parent, encoding="utf-8")
+            pipe = Pipe(command=f'{task["shell"]} {path.__str__()}\n', current_directory=path.parent, encoding="utf-8")
             if pipe.stdout:
                 with open(path.parent / "task.out", "a+") as fd:
                     fd.write(pipe.stdout)
             if pipe.stderr:
                 with open(path.parent / "task.err", "a+") as fd:
                     fd.write(pipe.stderr)
+            task["running"] = False
+            updateTask([task])
             deleteTask(task["pid"])
             time.sleep(1)
         else:
