@@ -3,9 +3,9 @@ from pydantic import BaseModel
 
 
 class Task(BaseModel):
-    pid: int
-    startTime: Union[int, None] = None
-    submitTime: Union[int, None] = None
+    pid: str
+    startTime: Union[float, None] = None
+    submitTime: Union[float, None] = None
     running: Union[bool, None] = None
     scriptPath: Union[str, None] = None
     shell: Union[str, None] = None
